==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/StyleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleDescription } from "./StyleDescription";
/**
 * @hidden
 */
export let StyleDescriptionMetadata = /*@__PURE__*/ (() => {
    class StyleDescriptionMetadata extends Base {
        static b(a) {
            if (StyleDescriptionMetadata.a == null) {
                StyleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StyleDescriptionMetadata.c(StyleDescriptionMetadata.a);
            }
            if (a.k(StyleDescriptionMetadata.a)) {
                return;
            }
            a.aa(StyleDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            StyleDescriptionMetadata.b(a);
            a.ac("Style", () => new StyleDescription());
            a.ab("Style", StyleDescriptionMetadata.a);
        }
    }
    StyleDescriptionMetadata.$t = /*@__PURE__*/ markType(StyleDescriptionMetadata, 'StyleDescriptionMetadata');
    StyleDescriptionMetadata.a = null;
    return StyleDescriptionMetadata;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/StyleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleDescription } from "./StyleDescription";
/**
 * @hidden
 */
export let StyleDescriptionMetadata = /*@__PURE__*/ (() => {
    class StyleDescriptionMetadata extends Base {
        static b(a) {
            if (StyleDescriptionMetadata.a == null) {
                StyleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StyleDescriptionMetadata.c(StyleDescriptionMetadata.a);
            }
            if (a.k(StyleDescriptionMetadata.a)) {
                return;
            }
            a.ac(StyleDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            StyleDescriptionMetadata.b(a);
            a.ae("Style", () => new StyleDescription());
            a.ad("Style", StyleDescriptionMetadata.a);
        }
    }
    StyleDescriptionMetadata.$t = /*@__PURE__*/ markType(StyleDescriptionMetadata, 'StyleDescriptionMetadata');
    StyleDescriptionMetadata.a = null;
    return StyleDescriptionMetadata;
})();
